==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/text/l10n/lv.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Datne tika augšupielādēta",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
    "File not found" : "Datne nav atrasta",
    "Text" : "Teksts",
    "Translate" : "Tulkot",
    "Use current version" : "Izmantot pašreizējo versiju",
    "Guest" : "Viesis",
    "Remove link" : "Noņemt saiti",
    "guest" : "viesis",
    "Offline" : "Bezsaistē",
    "Saving …" : "Saglabā ...",
    "Saved" : "Saglabāts",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Bold" : "Treknraksts",
    "Italic" : "Slīpraksts",
    "Strikethrough" : "Pārsvītrojums",
    "Link" : "Saite",
    "Action" : "Darbība",
    "Undo" : "Atsaukt",
    "Redo" : "Atcelt atsaukšanu",
    "URL" : "URL",
    "Update link" : "Atjaunināt saiti",
    "Select language" : "Izvēlies valodu",
    "to" : "kam",
    "Replace" : "Aizvietot",
    "Edit" : "Labot",
    "Source code" : "Izejas kods",
    "Insert link" : "Ievietojiet saiti",
    "Info" : "Info",
    "Warning" : "Brīdinājums",
    "Details" : "Detaļas",
    "Command" : "Komanda",
    "Add folder description" : "Pievienot mapes aprakstu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> php82-nextcloud-31.0.10.tgz: share/nextcloud/apps/text/l10n/lv.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Datne tika augšupielādēta",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
    "text document" : "teksta dokuments",
    "Editing session has expired. Please reload the page." : "Labošanas sesija ir beigusies. Lūgums pārlādēt lapu.",
    "{user} has mentioned you in the text document {node}" : "{user} pieminēja Tevi teksta dokumentā {node}",
    "File not found" : "Datne nav atrasta",
    "Text" : "Teksts",
    "Translate" : "Tulkot",
    "Guest" : "Viesis",
    "you" : "Tu",
    "edit" : "rediģēt",
    "Open in new tab" : "Atvērt jaunā cilnē",
    "Copy link" : "Ievietot saiti starpliktuvē",
    "Remove link" : "Noņemt saiti",
    "guest" : "viesis",
    "Offline" : "Bezsaistē",
    "Saving …" : "Saglabā ...",
    "Saved" : "Saglabāts",
    "Unsaved changes" : "Nesaglabātas izmaiņas",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Bold" : "Treknraksts",
    "Italic" : "Slīpraksts",
    "Strikethrough" : "Pārsvītrojums",
    "Link" : "Saite",
    "Action" : "Darbība",
    "Undo" : "Atsaukt",
    "Redo" : "Atcelt atsaukšanu",
    "Open link" : "Atvērt saiti",
    "Save changes" : "Saglabāt izmaiņas",
    "Cancel" : "Atcelt",
    "URL" : "URL",
    "Update link" : "Atjaunināt saiti",
    "Select language" : "Atlasīt valodu",
    "to" : "kam",
    "Replace" : "Aizvietot",
    "Upload" : "Augšupielādēt",
    "Insert Table" : "Ievietot tabulu",
    "Edit" : "Labot",
    "Source code" : "Izejas kods",
    "Done" : "Pabeigts",
    "Details" : "Informācija",
    "Insert link" : "Ievietojiet saiti",
    "Command" : "Komanda",
    "Choose" : "Izvēlēties",
    "Add folder description" : "Pievienot mapes aprakstu",
    "Copy link to clipboard" : "Ievietot saiti starpliktuvē"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
